@@ -20,20 +20,20 @@ def lock(outfile, content=None, infile=None, remove_infile=False):
     """
     # ensure only content or infile are provided
     if content and infile:
-        raise VaultError('cannot provide content and infile')
+        raise VaultError("cannot provide content and infile")
 
     check_outfile(outfile)
 
     # Get content from infile when there is no content
     if not content:
-        with open(infile, 'rb') as fh:
+        with open(infile, "rb") as fh:
             content = fh.read()
 
     content = bytearray(content)
 
     encrypted = zymkey.client.lock(content)
 
-    with open_with_perms(outfile, 'wb', 0o400) as fh:
+    with open_with_perms(outfile, "wb", 0o400) as fh:
         fh.write(encrypted)
 
     if remove_infile:
@@ -50,7 +50,7 @@ def unlock(infile):
     Returns (bytearray):
         Unlocked content
     """
-    with open(infile, 'rb') as fh:
+    with open(infile, "rb") as fh:
         encrypted = bytearray(fh.read())
 
     return zymkey.client.unlock(encrypted)
